fn write_item_body(
out: &mut String,
item: &Item<'_>,
comments: &CommentData,
ctx: &Ctx<'_>,
)Expand description
Render the common body of a struct, enum, event, error, or value type.
fn write_item_body(
out: &mut String,
item: &Item<'_>,
comments: &CommentData,
ctx: &Ctx<'_>,
)Render the common body of a struct, enum, event, error, or value type.