fn find_contract_id<'gcx>(
gcx: Gcx<'gcx>,
name: &str,
abs_sol_path: &Path,
) -> Option<ContractId>Expand description
Find the HIR ContractId for a contract by name, requiring the contract to
live in the source file currently being rendered (compared via absolute path)
so contracts that share a file stem across src/ and lib/ cannot collide.